@@ -27,12 +27,13 @@ import org.apache.ivy.util.CacheCleaner;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
 
+import org.apache.tools.ant.types.FileSet;
+import org.apache.tools.ant.types.Path;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 
 public class IvyRetrieveTest {
     private static final String IVY_RETRIEVE_PATTERN = "build/test/lib/[organisation]/[module]/ivy-[revision].xml";
@@ -77,6 +78,47 @@ public class IvyRetrieveTest {
             "mod1.2", "jar", "jar")).exists());
     }
 
+    @Test
+    public void testRetrieveToNonEmptyDirectory() throws IOException {
+        new File("build/test/lib").mkdirs();
+        new File("build/test/lib/foo.txt").createNewFile(); // make sure the retrieve dir is not empty
+
+        project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-simple.xml");
+
+        retrieve.setSetId("setId");
+        retrieve.setPathId("pathId");
+        retrieve.execute();
+
+        FileSet fileSet = project.getReference("setId");
+        assertNotNull(fileSet);
+        assertEquals(1, fileSet.size());
+
+        Path path = project.getReference("pathId");
+        assertNotNull(path);
+        assertEquals(1, path.size());
+    }
+
+    @Test
+    public void testEmptyRetrieveToNonEmptyDirectory() throws IOException {
+        new File("build/test/lib").mkdirs();
+        new File("build/test/lib/foo.txt").createNewFile(); // make sure the retrieve dir is not empty
+
+        project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-simple.xml");
+
+        retrieve.setType("foo"); // make sure we don't retrieve anything
+        retrieve.setSetId("setId");
+        retrieve.setPathId("pathId");
+        retrieve.execute();
+
+        FileSet fileSet = project.getReference("setId");
+        assertNotNull(fileSet);
+        assertEquals(0, fileSet.size());
+
+        Path path = project.getReference("pathId");
+        assertNotNull(path);
+        assertEquals(0, path.size());
+    }
+
     @Test
     public void testRetrievePrivateWithWildcard() {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-381.xml");
